aboutsummaryrefslogtreecommitdiffstats
path: root/tests/unit/core
diff options
context:
space:
mode:
authorMichał Gołębiowski-Owczarek <m.goleb@gmail.com>2019-12-08 22:23:08 +0100
committerMichał Gołębiowski-Owczarek <m.goleb@gmail.com>2019-12-08 22:23:08 +0100
commit98b539171b6e805fa79346a5e9896865e5213b9c (patch)
treef6c296195f081c538f90c96f43f28012670960a5 /tests/unit/core
parent74f8a0ac952f6f45f773312292baef1c26d81300 (diff)
downloadjquery-ui-98b539171b6e805fa79346a5e9896865e5213b9c.tar.gz
jquery-ui-98b539171b6e805fa79346a5e9896865e5213b9c.zip
All: Migrate away from deprecated/removed Core APIs
Summary of the changes: * Build: Add jQuery 3.2.0-3.4.1 to versions UI can be tested against * Build: Load jQuery & Migrate via HTTPS * Build: Add package-lock.json to .gitignore * Build: Update jQuery Migrate from 3.0.0 to 3.1.0 * Build: Allow to run tests against jQuery 3.x-git * Build: Fix formatting according to JSCS rules * Build: Disable JSCS for the inlined jQuery Color * All: Switch from $.isArray to Array.isArray (jQuery.isArray will be removed in jQuery 4.0) * All: Switch from `$.isFunction( x )` to `typeof x === "function"` (jQuery.isFunction will be removed in jQuery 4.0) * All: Inline jQuery.isWindow as it'll be removed in jQuery 4.0 * Effects: Fix a timing issue in a variable declaration. Previously, a jQuery object was created, chained & assigned to a variable that was then accessed in a callback used inside of this chained definition. Due to a timing difference in when the callback fired for the first time in latest jQuery master, it was being called before the variable was defined. * Tests: Make dialog & draggable unit tests less strict (newest jQuery returns fractional results in some cases, making comparisons fail when there's a tiny difference) * All: Migrate from $.trim to bare String.prototype.trim (jQuery.trim will be deprecated in jQuery 3.5) Closes gh-1901
Diffstat (limited to 'tests/unit/core')
-rw-r--r--tests/unit/core/core.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/tests/unit/core/core.js b/tests/unit/core/core.js
index b5b6b3b81..acfc291ff 100644
--- a/tests/unit/core/core.js
+++ b/tests/unit/core/core.js
@@ -152,8 +152,9 @@ QUnit.test( "Labels", function( assert ) {
var found = labels.map( function() {
// Support: Core 1.9 Only
- // We use $.trim() because core 1.9.x silently fails when white space is present
- return $.trim( $( this ).text() );
+ // We use String.prototype.trim because core 1.9.x silently fails
+ // when white space is present
+ return String.prototype.trim.call( $( this ).text() );
} ).get();
assert.deepEqual( found, expected,